pyoti.region package
====================

Submodules
----------

pyoti.region.record module
--------------------------

.. automodule:: pyoti.region.record
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.region.region module
--------------------------

.. automodule:: pyoti.region.region
    :members:
    :undoc-members:
    :show-inheritance:

pyoti.region.view module
------------------------

.. automodule:: pyoti.region.view
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyoti.region
    :members:
    :undoc-members:
    :show-inheritance:
